#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://www.tuxpaint.org/
# source location	 : http://downloads.sourceforge.net/tuxpaint/tuxpaint-0.9.21.tar.gz
# last revised       : 02.12.2009
# dep                : 

softname='tuxpaint'
softversion='0.9.21'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src=$buildir/$softname-$softversion
srcpkg=$buildir/$softname-$softversion.tar.gz
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/tuxpaint/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
tuxpaint: tuxpaint - drawing program for children
tuxpaint:
tuxpaint: Tux Paint is a free, award-winning drawing program for children ages 3
tuxpaint: to 12 (for example, preschool and K-6 in the US, key stages 1 & 2 in
tuxpaint: the UK). It combines an easy-to-use interface, fun sound effects, and
tuxpaint: an encouraging cartoon mascot who guides children as they use the
tuxpaint: program.
tuxpaint:
tuxpaint:
tuxpaint: 
tuxpaint:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# Patch Makefile
	sed -i 's|PREFIX:=/usr/local|PREFIX:=/usr|' \
		./Makefile
	sed -i 's|DOC_PREFIX:=$(DESTDIR)$(PREFIX)/share/doc/tuxpaint|DOC_PREFIX:=$(DESTDIR)$(PREFIX)/doc/tuxpaint|' \
		./Makefile
	sed -i 's|DEVDOC_PREFIX:=$(DESTDIR)$(PREFIX)/share/doc/tuxpaint-dev|DEVDOC_PREFIX:=$(DESTDIR)$(PREFIX)/doc/tuxpaint-dev|' \
		./Makefile
	sed -i 's|MAN_PREFIX:=$(DESTDIR)$(PREFIX)/share/man|MAN_PREFIX:=$(DESTDIR)$(PREFIX)/man|' \
		./Makefile
	sed -i 's|DEVMAN_PREFIX:=$(DESTDIR)$(PREFIX)/share/man|DEVMAN_PREFIX:=$(DESTDIR)$(PREFIX)/man|' \
		./Makefile	
	sed -i 's|install-gnome install-kde install-kde-icons||' \
		./Makefile
	sed -i 's|install-icon install-gettext|install-gettext|' \
		./Makefile

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
 
make
make install DESTDIR=$dest

# make icon
	for SIZE in 16x16 22x22 32x32 48x48 64x64 96x96 128x128 192x192; do
		mkdir -p $dest/usr/share/icons/hicolor/$SIZE/apps
		cd $dest/usr/share/icons/hicolor/$SIZE/apps
		ln -s ../../../../$softname/images/icon$SIZE.png $softname.png
	done

# make .desktop
cp $buildir/$softname.desktop $dest/usr/share/applications/

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
    README.txt \
    $dest/usr/doc/$softname-$softversion

mv $dest/usr/doc/$softname $dest/usr/doc/$softname-$softversion
mv $dest/usr/doc/$softname-dev $dest/usr/doc/$softname-$softversion
	
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "SDL_Pango,bzip2,cairo,expat,fontconfig,freetype,fribidi,glib2,\
glitz,gtk+2,libX11,libXau,libXdmcp,libXrender,libcroco,libgsf,libjpeg,\
libmad,libmikmod,libpaper,libpng,librsvg,libtiff,libxcb,libxml2,pango,\
pixman,sdl,xcb-util,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/tuxmath/source/build-tuxmath.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
